@@ -1,8 +1,7 @@
 import requests
-import socks
-import socket
 
 
+# 保存远程URL图片到本地
 def saveImg(url, fileName="file", path=".\\"):
     """
         保存图片到本地
